Crate kcr_networking_istio_io

Crate kcr_networking_istio_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the networking.istio.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

networking.istio.io/v1

  • DestinationRule
  • Gateway
  • ServiceEntry
  • Sidecar
  • VirtualService
  • WorkloadEntry
  • WorkloadGroup

networking.istio.io/v1alpha3

  • DestinationRule
  • EnvoyFilter
  • Gateway
  • ServiceEntry
  • Sidecar
  • VirtualService
  • WorkloadEntry
  • WorkloadGroup

networking.istio.io/v1beta1

  • DestinationRule
  • Gateway
  • ProxyConfig
  • ServiceEntry
  • Sidecar
  • VirtualService
  • WorkloadEntry
  • WorkloadGroup

Modules

v1
v1alpha3
v1beta1