This crate contains kube-rs compatible bindings for Kubernetes custom resources for the networking.istio.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
networking.istio.io/v1
DestinationRuleGatewayServiceEntrySidecarVirtualServiceWorkloadEntryWorkloadGroup
networking.istio.io/v1alpha3
DestinationRuleEnvoyFilterGatewayServiceEntrySidecarVirtualServiceWorkloadEntryWorkloadGroup
networking.istio.io/v1beta1
DestinationRuleGatewayProxyConfigServiceEntrySidecarVirtualServiceWorkloadEntryWorkloadGroup